# Torch PSO

Particle Swarm Optimization is an optimization technique that iteratively attempts to improve a list of candidate
solutions. Each candidate solution is called a "particle", and collectively they are called a "swarm". In each step of
the optimization, each particle moves in a random directly while simultaneously being pulled towards the other particles
in the swarm. A simple introduction to the algorithm can be found on 
[its Wikipedia article](https://en.wikipedia.org/wiki/Particle_swarm_optimization).

This package implements the Particle Swarm Optimization using the PyTorch Optimizer API, making it compatible with 
most pre-existing Torch training loops.

## Installation
TODO: Write installation instructions for PyPI